cordova.define("com.sf.cordova.sfuserapi.SFUserAPI", function(require, exports, module) { 

var exec = require('cordova/exec');

/**
 * 提供用户相关接口，如登录、注册以及用户信息修改接口等等
 */
               
module.exports = {
   /**
    * 是否已经登录，启动时判断下
    *
    * @param {Function} successCallback  成功回调，返回ture/false (实际是0和1)
    */
   isLogin: function(successCallback) {
      exec(successCallback, null, "SFUserAPI", "isLogin", []);
   },
   /**
    * 登录成功后可通过此接口获取请求安全相关的所有信息
    *
    * @param {Function} successCallback  成功回调，{token:{token},user:{user},device:{device},appInfo:{appInfo}}
    */
   getTokenInfo: function(successCallback) {
      exec(successCallback, null, "SFUserAPI", "getTokenInfo", []);
   },
   /**
    * 手机号注册接口
    *
    * @param {String} mobile             手机号，可以带国家码（+8615673886666）
    * @param {String} smsCode            短信验证码
    * @param {String} password           设置的初始密码
    * @param {Function} successCallback  成功回调，返回当前注册用户，并直接登录成功 {token:token,user:{user},device:{device},appInfo:{appInfo}}
    * @param {Function} errorCallback    错误回调，返回error @see error
    */
   regist: function(mobile, smsCode, password, successCallback, errorCallback) {

      var param = {
        mobile:mobile,
        smsCode:smsCode,
        password:password
      };

      exec(successCallback, errorCallback, "SFUserAPI", "regist", [param]);
   },
    /**
    * 登录接口
    *
    * @param {String} account            账号，手机号或者邮箱
    * @param {String} password           设置的初始密码
    * @param {Function} successCallback  成功回调，返回当前注册用户，并直接登录成功 {token:token,user:{user},device:{device},appInfo:{appInfo}}
    * @param {Function} errorCallback    错误回调，返回error @see error
    */
   login: function(account, password, successCallback, errorCallback) {

      var param = {
        account:account,
        password:password
      };

      exec(successCallback, errorCallback, "SFUserAPI", "login", [param]);
   },
   /**
    * 忘记密码接口
    *
    * @param {String} mobile             手机号
    * @param {String} smsCode            短信验证码
    * @param {String} password           设置的新密码
    * @param {Function} successCallback  成功回调，返回{success:ture}
    * @param {Function} errorCallback    错误回调，返回error @see error
    */
   forgetPassword: function(mobile, smsCode, password, successCallback, errorCallback) {

      var param = {
        mobile:mobile,
        smsCode:smsCode,
        password:password
      };

      exec(successCallback, errorCallback, "SFUserAPI", "forgetPassword", [param]);
   },
   /**
    * 注销接口
    *
    * @param {Function} successCallback  成功回调，返回{success:ture}
    * @param {Function} errorCallback    错误回调，返回error @see error
    */
   logout: function(successCallback, errorCallback) {
      exec(successCallback, errorCallback, "SFUserAPI", "logout", []);
   },
   /**
    * 用户是否已经存在
    *
    * @param {String} account            账号，手机号或者邮箱
    * @param {Function} successCallback  成功回调，返回{success:ture}
    * @param {Function} errorCallback    错误回调，返回error @see error
    */
   existUser: function(account, successCallback, errorCallback) {

      var param = {
        account:account
      };

      exec(successCallback, errorCallback, "SFUserAPI", "existUser", [param]);
   },
   /**
    * 获取当前登录用户信息
    *
    * @param {Function} successCallback  成功回调， 返回当前用户信息，@see user
    * @param {Function} errorCallback    错误回调，返回error @see error
    */
   getUserInfo: function(successCallback, errorCallback) {
      exec(successCallback, errorCallback, "SFUserAPI", "getUserInfo", []);
   },
   /**
    * 修改当前登录用户昵称
    *
    * @param {String} nickname           需要设置的nickname，不能为空
    * @param {Function} successCallback  成功回调，返回{success:ture}
    * @param {Function} errorCallback    错误回调，返回error @see error
    */
   modifyNickname: function(nickname, successCallback, errorCallback) {

      var param = {
        nickname:nickname
      };

      exec(successCallback, errorCallback, "SFUserAPI", "modifyNickname", [param]);
   },
   /**
    * 修改用户头像
    *
    * @param {String} avatar             新头像url
    * @param {Function} successCallback  成功回调，返回{success:ture}
    * @param {Function} errorCallback    错误回调，返回error @see error
    */
   modifyAvatar: function(avatar, successCallback, errorCallback) {

      var param = {
        avatar:avatar
      };
      
      exec(successCallback, errorCallback, "SFUserAPI", "modifyAvatar", [param]);
   },
   /**
    * 下发验证码
    *
    * @param {String} mobile             手机号
    * @param {String} askFor             请求类型{REGISTER,RESETPSWD}
    * @param {Function} successCallback  成功回调，返回{success:ture}
    * @param {Function} errorCallback    错误回调，返回error @see error
    */
   requestSMSCode: function(mobile, askFor, successCallback, errorCallback) {

      var param = {
        mobile:mobile,
        askFor:askFor
      };
      
      exec(successCallback, errorCallback, "SFUserAPI", "requestSMSCode", [param]);
   },
   /**
    * 验证验证码
    *
    * @param {String} mobile             手机号
    * @param {String} smsCode            手机验证码
    * @param {String} askFor             验证码请求类型{REGISTER,RESETPSWD}
    * @param {Function} successCallback  成功回调，返回{success:ture}
    * @param {Function} errorCallback    错误回调，返回error @see error
    */
   checkSMSCode: function(mobile, smsCode, askFor, successCallback, errorCallback) {

      var param = {
        mobile:mobile,
        smsCode:smsCode,
        askFor:askFor
      };
      
      exec(successCallback, errorCallback, "SFUserAPI", "checkSMSCode", [param]);
   },
   /**
    * 重置密码
    *
    * @param {String} newPassword        新密码
    * @param {String} oldPassword        老密码
    * @param {Function} successCallback  成功回调，返回{success:ture}
    * @param {Function} errorCallback    错误回调，返回error @see error
    */
   resetPassword: function(newPassword, oldPassword, successCallback, errorCallback) {

      var param = {
        newPassword:newPassword,
        oldPassword:oldPassword
      };
      
      exec(successCallback, errorCallback, "SFUserAPI", "resetPassword", [param]);
   }
};

});
